pub struct EffectBoundary {
pub effect: Box<Effect>,
pub principal: String,
pub context: Option<HashMap<String, Value>>,
}Expand description
EffectBoundary : The boundary contract for submitting effects to the kernel
Fields
effect: Box<Effect>principal: StringAgent/user identity (e.g. agent:analyst)
context: Option<HashMap<String, Value>>Additional context (jurisdiction, industry, budget state)
Implementations
Sourceimpl EffectBoundary
impl EffectBoundary
Sourcepub fn new(effect: Effect, principal: String) -> EffectBoundary
pub fn new(effect: Effect, principal: String) -> EffectBoundary
The boundary contract for submitting effects to the kernel