pub struct OssLocalProofgraphResponse {
pub nodes: Option<Option<Value>>,
pub path: Option<String>,
pub status: Option<String>,
pub message: Option<String>,
}Expand description
OssLocalProofgraphResponse : Local proofgraph payload. When the file is unavailable, status is unavailable and nodes is empty.
Fields
nodes: Option<Option<Value>>path: Option<String>status: Option<String>message: Option<String>Implementations
Sourceimpl OssLocalProofgraphResponse
impl OssLocalProofgraphResponse
Sourcepub fn new() -> OssLocalProofgraphResponse
pub fn new() -> OssLocalProofgraphResponse
Local proofgraph payload. When the file is unavailable, status is unavailable and nodes is empty.